# SOCO-Core Python SDK
Python client to use SOCO answer-as-as-service platform.

## Install 
    pip3 install soco-core-python
    
## Requirements
    python 3
    
## Quick Start

This following example can be found at: quick_start.py. To see more examples, check out /examples folder

First of all, register at [SOCO Dashboard](https://app.soco.ai) After get your **API_KEYs**, you can setup an SOCO application
using a few lines of code!

Check out [quick_start.py](https://github.com/soco-ai/soco-core-python/blob/master/quick_start.py) for a quick example. 

Check out our awesome [tutorial list](https://github.com/soco-ai/soco-core-python/tree/master/examples) to find out more use cases.
    
    
## Citation
If you use SOCO in research, we would love to be cited:

```latex
    @misc{soco2019engine,
      title={SOCO: Answer Engine Platform},
      author={Tiancheng Zhao and Kyusong Lee},
      howpublished={\url{https://github.com/soco-ai/soco-core-python}},
      year={2019}
    }
```
